@@ -9,7 +9,7 @@ Note that this interface uses the Numpy style python docstrings.
 import logging
 import sys
 
-__version__ = "0.2.1"
+__version__ = "0.2.5"
 
 
 ##################
@@ -59,6 +59,9 @@ def get_logger(name: str, stream: bool = False) -> logging.Logger:
     ----------
     name : str
         The name of the module to be logged.
+    stream : bool
+        Determine whether to log to console or to a file,
+        by default False.
 
     Returns
     -------
